# -*- coding: utf-8 -*-
from django.utils.translation import ugettext_lazy as _


trans_app_label = _(u'Flatpages')
